@@ -163,7 +163,7 @@ int canonicalize(const char *path, char *resolved_path)
 		 * an absolute path
 		 */
 
-		if (ENAMETOOLONG == errno)
+		if (errno_is_too_long())
 			return -1;
 
 		if (NULL == egetcwd(resolved_path, SB_PATH_MAX - 2))
@@ -172,7 +172,7 @@ int canonicalize(const char *path, char *resolved_path)
 		snprintf(resolved_path + len, SB_PATH_MAX - len, "/%s", path);
 
 		if (NULL == erealpath(resolved_path, resolved_path)) {
-			if (errno == ENAMETOOLONG) {
+			if (errno_is_too_long()) {
 				/* The resolved path is too long for the buffer to hold */
 				return -1;
 			} else {
@@ -343,6 +343,34 @@ char *egetcwd(char *buf, size_t size)
 	return tmpbuf;
 }
 
+static int sb_copy_file_to_fd(const char *file, int ofd)
+{
+	int ifd = sb_open(file, O_RDONLY, 0);
+	if (ifd == -1)
+		return -1;
+
+	size_t pagesz = getpagesize();
+	char *buf = xmalloc(pagesz);
+	while (1) {
+		size_t len = sb_read(ifd, buf, pagesz);
+		if (len == -1)
+			goto error;
+		else if (!len)
+			break;
+		size_t i;
+		for (i = 0; i < len; ++i)
+			if (!buf[i])
+				buf[i] = ' ';
+		SB_WRITE(ofd, buf, len, error);
+	}
+	sb_close(ifd);
+	free(buf);
+
+	return 0;
+ error:
+	return -1;
+}
+
 void sb_dump_backtrace(void)
 {
 #ifdef HAVE_BACKTRACE
@@ -351,6 +379,10 @@ void sb_dump_backtrace(void)
 	num_funcs = backtrace(funcs, ARRAY_SIZE(funcs));
 	backtrace_symbols_fd(funcs, num_funcs, STDERR_FILENO);
 #endif
+	const char *cmdline = sb_get_cmdline(trace_pid);
+	sb_printf("%s: ", cmdline);
+	sb_copy_file_to_fd(cmdline, STDERR_FILENO);
+	sb_printf("\n\n");
 }
 
 __attribute__((noreturn))
@@ -382,34 +414,6 @@ void sb_abort(void)
 	abort();
 }
 
-int sb_copy_file_to_fd(const char *file, int ofd)
-{
-	int ifd = sb_open(file, O_RDONLY, 0);
-	if (ifd == -1)
-		return -1;
-
-	size_t pagesz = getpagesize();
-	char *buf = xmalloc(pagesz);
-	while (1) {
-		size_t len = sb_read(ifd, buf, pagesz);
-		if (len == -1)
-			goto error;
-		else if (!len)
-			break;
-		size_t i;
-		for (i = 0; i < len; ++i)
-			if (!buf[i])
-				buf[i] = ' ';
-		SB_WRITE(ofd, buf, len, error);
-	}
-	sb_close(ifd);
-	free(buf);
-
-	return 0;
- error:
-	return -1;
-}
-
 #define _SB_WRITE_STR(str) SB_WRITE(logfd, str, strlen(str), error)
 static bool write_logfile(const char *logfile, const char *func, const char *path,
                           const char *apath, const char *rpath, bool access)
@@ -545,7 +549,7 @@ static void init_env_entries(char ***prefixes_array, int *prefixes_num, const ch
 
 	/* num_delimiters might be 0, and we need 2 entries at least */
 	pfx_array = xmalloc(((num_delimiters * 2) + 2) * sizeof(char *));
-	buffer = strdup(prefixes_env);
+	buffer = xstrdup(prefixes_env);
 	buffer_ptr = buffer;
 
 #ifdef HAVE_STRTOK_R
@@ -756,7 +760,7 @@ static int check_access(sbcontext_t *sbcontext, int sb_nr, const char *func,
 			if (1 == retval) { /* Does have write access on path */
 				char *dname, *dname_buf, *rpath;
 
-				dname_buf = strdup(abs_path);
+				dname_buf = xstrdup(abs_path);
 				dname = dirname(dname_buf);
 				/* Get symlink resolved path */
 				rpath = resolve_path(dname, 1);
@@ -799,7 +803,7 @@ static int check_access(sbcontext_t *sbcontext, int sb_nr, const char *func,
 		 * exist.  All the functions filtered thus far fall into that
 		 * behavior category, so no need to check the syscall.
 		 */
-		char *dname_buf = strdup(resolv_path);
+		char *dname_buf = xstrdup(resolv_path);
 		int aret = sb_unwrapped_access(dirname(dname_buf), F_OK);
 		free(dname_buf);
 		if (aret) {
@@ -912,7 +916,7 @@ static int check_syscall(sbcontext_t *sbcontext, int sb_nr, const char *func,
 	/* The path is too long to be canonicalized, so just warn and let the
 	 * function handle it (see bugs #21766 #94630 #101728 #227947)
 	 */
-	if (ENAMETOOLONG == errno) {
+	if (errno_is_too_long()) {
 		free(absolute_path);
 		free(resolved_path);
 		return 2;
@@ -926,9 +930,6 @@ static int check_syscall(sbcontext_t *sbcontext, int sb_nr, const char *func,
 	SB_EERROR("ISE ", "%s(%s): %s\n"
 		"\tabs_path: %s\n" "\tres_path: %s\n",
 		func, file, strerror(errno), absolute_path, resolved_path);
-	const char *cmdline = sb_get_cmdline(trace_pid);
-	sb_copy_file_to_fd(cmdline, STDERR_FILENO);
-	sb_printf("\n%s\n", cmdline);
 	sb_abort();
 }
 
@@ -982,7 +983,7 @@ bool before_syscall(int dirfd, int sb_nr, const char *func, const char *file, in
 		ssize_t ret = readlink(at_file_buf, at_file_buf, at_len);
 		if (ret == -1) {
 			/* see comments at end of check_syscall() */
-			if (errno == ENAMETOOLONG) {
+			if (errno_is_too_long()) {
 				restore_errno();
 				return true;
 			}
@@ -1032,7 +1033,7 @@ bool before_syscall(int dirfd, int sb_nr, const char *func, const char *file, in
 			if (sb_env) {
 				init_env_entries(&(sbcontext.prefixes[i]),
 					&(sbcontext.num_prefixes[i]), sb_env_names[i], sb_env, 1);
-				cached_env_vars[i] = strdup(sb_env);
+				cached_env_vars[i] = xstrdup(sb_env);
 			} else
 				cached_env_vars[i] = NULL;
 		}
