@@ -26,6 +26,13 @@ pid_t trace_pid;
 
 static volatile bool child_stopped;
 
+static void trace_exit(int status)
+{
+	/* if we were vfork-ed, clear trace_pid and exit */
+	trace_pid = 0;
+	_exit(status);
+}
+
 static long _do_ptrace(enum __ptrace_request request, const char *srequest, void *addr, void *data)
 {
 	long ret;
@@ -33,8 +40,12 @@ static long _do_ptrace(enum __ptrace_request request, const char *srequest, void
 	errno = 0;
 	ret = ptrace(request, trace_pid, addr, data);
 	if (ret == -1) {
-		/* Child hasn't gotten to the next marker yet */
+		/* Child hasn't gotten to the next marker yet ? */
 		if (errno == ESRCH) {
+			int status;
+			if (waitpid(trace_pid, &status, 0) == -1)
+				/* nah, it's dead ... should we whine though ? */
+				trace_exit(0);
 			sched_yield();
 			goto try_again;
 		} else if (!errno)
@@ -114,23 +125,19 @@ static const char *strsig(int sig)
 {
 	switch (sig) {
 #define S(s) case SIG##s: return "SIG"#s;
+	S(ABRT)
 	S(CHLD)
 	S(CONT)
+	S(HUP)
 	S(KILL)
-	S(TRAP)
+	S(SEGV)
 	S(STOP)
+	S(TRAP)
 #undef S
 	default: return "SIG???";
 	}
 }
 
-static void trace_exit(int status)
-{
-	/* if we were vfork-ed, clear trace_pid and exit */
-	trace_pid = 0;
-	_exit(status);
-}
-
 static void trace_child_signal(int signo, siginfo_t *info, void *context)
 {
 	SB_DEBUG("got sig %s(%i): code:%s(%i) status:%s(%i)",
@@ -156,11 +163,21 @@ static void trace_child_signal(int signo, siginfo_t *info, void *context)
 				case SIGCONT:
 					return;
 			}
-			/* fall through */
+
+			/* For whatever signal the child caught, let's ignore it and
+			 * continue on.  If it aborted, segfaulted, whatever, that's
+			 * its problem, not ours, so don't whine about it.  We just
+			 * have to be sure to bubble it back up.  #265072
+			 */
+			do_ptrace(PTRACE_CONT, NULL, (void *)(long)info->si_status);
+			return;
 	}
 
-	SB_EERROR("ISE:trace_child_signal ", "child signal %i, code %i, status %i\n",
-		signo, info->si_code, info->si_status);
+	SB_EERROR("ISE:trace_child_signal ", "child (%i) signal %s(%i), code %s(%i), status %s(%i)\n",
+		trace_pid,
+		strsig(signo), signo,
+		strcld_chld(info->si_code), info->si_code,
+		strsig(info->si_status), info->si_status);
 }
 
 static const struct syscall_entry *lookup_syscall_in_tbl(const struct syscall_entry *tbl, int nr)
@@ -311,9 +328,16 @@ static bool trace_check_syscall(const struct syscall_entry *se, void *regs)
 	return ret;
 }
 
+/* Some arches (like hppa) don't implement PTRACE_GETREGS ...
+ * what a bunch of asshats.
+ */
+#ifndef trace_get_regs
+# define trace_get_regs(regs) do_ptrace(PTRACE_GETREGS, NULL, regs);
+#endif
+
 static void trace_loop(void)
 {
-	struct user_regs_struct regs;
+	trace_regs regs;
 	bool before_syscall;
 	long ret;
 	int nr, exec_state;
@@ -332,7 +356,7 @@ static void trace_loop(void)
 			se = lookup_syscall_in_tbl(tbl_at_fork, nr);
 			if (!before_syscall || !se || se->sys != SB_NR_EXECVE) {
 				if (before_syscall)
-					_SB_DEBUG("%s:%i", se ? se->name : "IDK", nr);
+					_SB_DEBUG(">%s:%i", se ? se->name : "IDK", nr);
 				else
 					__SB_DEBUG("(...) = ...\n");
 				goto loop_again;
@@ -341,7 +365,7 @@ static void trace_loop(void)
 		}
 
 		se = lookup_syscall(nr);
-		ret = do_ptrace(PTRACE_GETREGS, NULL, &regs);
+		ret = trace_get_regs(&regs);
 		if (before_syscall) {
 			_SB_DEBUG("%s:%i", se ? se->name : "IDK", nr);
 			if (!trace_check_syscall(se, &regs)) {
