@@ -7,7 +7,7 @@
 
 #define WRAPPER_ARGS_PROTO const char *pathname
 #define WRAPPER_ARGS pathname
-#define WRAPPER_SAFE() FUNCTION_SANDBOX_SAFE(pathname)
+#define WRAPPER_SAFE() SB_SAFE(pathname)
 #define sb_unlinkat_pre_check sb_unlink_pre_check
 #include "unlinkat.c"
 #undef sb_unlinkat_pre_check
