@@ -7,5 +7,5 @@
 
 #define WRAPPER_ARGS_PROTO const char *filename, const struct timeval times[]
 #define WRAPPER_ARGS filename, times
-#define WRAPPER_SAFE() FUNCTION_SANDBOX_SAFE(filename)
+#define WRAPPER_SAFE() SB_SAFE(filename)
 #include "__wrapper_simple.c"
